==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeCDATASection.h <==
// class gnu.xml.libxmlj.dom.GnomeCDATASection

// class file dependencies
// @dep_class ee5c4d20f5b5ce2b gnu_xml_libxmlj_dom_GnomeCDATASection
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 6dd1f7372acd9c60 gnu_xml_libxmlj_dom_GnomeText
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeText

#include "gnu/xml/libxmlj/dom/GnomeText.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	gnu_xml_libxmlj_dom_GnomeText;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods	gnu_xml_libxmlj_dom_GnomeCDATASection;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs	gnu_xml_libxmlj_dom_GnomeCDATASection;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCDATASection;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object {
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeCDATASection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeCDATASection.h <==
// class gnu.xml.libxmlj.dom.GnomeCDATASection

// class file dependencies
// @dep_class ee5c4d20f5b5ce2b gnu_xml_libxmlj_dom_GnomeCDATASection
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 6dd1f7372acd9c60 gnu_xml_libxmlj_dom_GnomeText
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeText

#include "gnu/xml/libxmlj/dom/GnomeText.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	gnu_xml_libxmlj_dom_GnomeText;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vmethods	gnu_xml_libxmlj_dom_GnomeCDATASection;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_refs	gnu_xml_libxmlj_dom_GnomeCDATASection;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCDATASection;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$object {
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeCDATASection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$vtype _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeCDATASection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeCDATASection$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeCDATASection_H_ */
